@@ -45,6 +45,7 @@
 #include <QtCore/private/qjnihelpers_p.h>
 #include "android/devicediscoverybroadcastreceiver_p.h"
 #include <QtAndroidExtras/QAndroidJniEnvironment>
+#include <QtAndroid>
 
 QT_BEGIN_NAMESPACE
 
@@ -66,11 +67,20 @@ QBluetoothDeviceDiscoveryAgentPrivate::QBluetoothDeviceDiscoveryAgentPrivate(
     leScanTimeout(0),
     pendingCancel(false),
     pendingStart(false),
+    lowEnergySearchTimeout(25000),
     q_ptr(parent)
 {
+    QAndroidJniEnvironment env;
     adapter = QAndroidJniObject::callStaticObjectMethod("android/bluetooth/BluetoothAdapter",
                                                         "getDefaultAdapter",
                                                         "()Landroid/bluetooth/BluetoothAdapter;");
+    if (!adapter.isValid()) {
+        if (env->ExceptionCheck()) {
+            env->ExceptionDescribe();
+            env->ExceptionClear();
+        }
+        qCWarning(QT_BT_ANDROID) << "Device does not support Bluetooth";
+    }
 }
 
 QBluetoothDeviceDiscoveryAgentPrivate::~QBluetoothDeviceDiscoveryAgentPrivate()
@@ -93,8 +103,16 @@ bool QBluetoothDeviceDiscoveryAgentPrivate::isActive() const
     return m_active != NoScanActive;
 }
 
-void QBluetoothDeviceDiscoveryAgentPrivate::start()
+QBluetoothDeviceDiscoveryAgent::DiscoveryMethods QBluetoothDeviceDiscoveryAgent::supportedDiscoveryMethods()
 {
+    return (LowEnergyMethod | ClassicMethod);
+}
+
+void QBluetoothDeviceDiscoveryAgentPrivate::start(QBluetoothDeviceDiscoveryAgent::DiscoveryMethods methods)
+{
+    //TODO Implement discovery method handling (see input parameter)
+    requestedMethods = methods;
+
     if (pendingCancel) {
         pendingStart = true;
         return;
@@ -128,6 +146,34 @@ void QBluetoothDeviceDiscoveryAgentPrivate::start()
         return;
     }
 
+    // check Android v23+ permissions
+    // -> BTLE search requires android.permission.ACCESS_COARSE_LOCATION
+    if (requestedMethods & QBluetoothDeviceDiscoveryAgent::LowEnergyMethod
+        && QtAndroid::androidSdkVersion() >= 23)
+    {
+        QString permission(QLatin1String("android.permission.ACCESS_COARSE_LOCATION"));
+
+        // do we have required permission already, if so nothing to do
+        if (QtAndroidPrivate::checkPermission(permission) == QtAndroidPrivate::PermissionsResult::Denied) {
+            qCWarning(QT_BT_ANDROID) << "Requesting ACCESS_COARSE_LOCATION permission";
+
+            QAndroidJniEnvironment env;
+            const QHash<QString, QtAndroidPrivate::PermissionsResult> results =
+                    QtAndroidPrivate::requestPermissionsSync(env, QStringList() << permission);
+            if (!results.contains(permission)
+                || results[permission] == QtAndroidPrivate::PermissionsResult::Denied)
+            {
+                qCWarning(QT_BT_ANDROID) << "Search not possible due to missing permission (ACCESS_COARSE_LOCATION)";
+                lastError = QBluetoothDeviceDiscoveryAgent::UnknownError;
+                errorString = QBluetoothDeviceDiscoveryAgent::tr("Missing Location permission. Search is not possible");
+                emit q->error(lastError);
+                return;
+            }
+        }
+
+        qCWarning(QT_BT_ANDROID) << "ACCESS_COARSE_LOCATION permission available";
+    }
+
     // install Java BroadcastReceiver
     if (!receiver) {
         // SDP based device discovery
@@ -140,18 +186,35 @@ void QBluetoothDeviceDiscoveryAgentPrivate::start()
 
     discoveredDevices.clear();
 
-    const bool success = adapter.callMethod<jboolean>("startDiscovery");
-    if (!success) {
-        lastError = QBluetoothDeviceDiscoveryAgent::InputOutputError;
-        errorString = QBluetoothDeviceDiscoveryAgent::tr("Discovery cannot be started");
-        emit q->error(lastError);
-        return;
+    // by arbitrary definition we run classic search first
+    if (requestedMethods & QBluetoothDeviceDiscoveryAgent::ClassicMethod) {
+        const bool success = adapter.callMethod<jboolean>("startDiscovery");
+        if (!success) {
+            lastError = QBluetoothDeviceDiscoveryAgent::InputOutputError;
+            errorString = QBluetoothDeviceDiscoveryAgent::tr("Classic Discovery cannot be started");
+            emit q->error(lastError);
+            return;
+        }
+
+        m_active = SDPScanActive;
+        qCDebug(QT_BT_ANDROID)
+            << "QBluetoothDeviceDiscoveryAgentPrivate::start() - Classic search successfully started.";
+    } else {
+        // LE search only requested
+        Q_ASSERT(requestedMethods & QBluetoothDeviceDiscoveryAgent::LowEnergyMethod);
+
+        if (QtAndroidPrivate::androidSdkVersion() < 18) {
+            qCDebug(QT_BT_ANDROID) << "Skipping Bluetooth Low Energy device scan due to"
+                                      "insufficient Android version.";
+            m_active = NoScanActive;
+            lastError = QBluetoothDeviceDiscoveryAgent::UnsupportedDiscoveryMethod;
+            errorString = QBluetoothDeviceDiscoveryAgent::tr("Low Energy Discovery not supported");
+            emit q->error(lastError);
+            return;
+        }
+
+        startLowEnergyScan();
     }
-
-    m_active = SDPScanActive;
-
-    qCDebug(QT_BT_ANDROID)
-        << "QBluetoothDeviceDiscoveryAgentPrivate::start() - successfully executed.";
 }
 
 void QBluetoothDeviceDiscoveryAgentPrivate::stop()
@@ -162,6 +225,9 @@ void QBluetoothDeviceDiscoveryAgentPrivate::stop()
         return;
 
     if (m_active == SDPScanActive) {
+        if (pendingCancel)
+            return;
+
         pendingCancel = true;
         pendingStart = false;
         bool success = adapter.callMethod<jboolean>("cancelDiscovery");
@@ -192,7 +258,7 @@ void QBluetoothDeviceDiscoveryAgentPrivate::processSdpDiscoveryFinished()
         emit q->canceled();
     } else if (pendingStart) {
         pendingStart = pendingCancel = false;
-        start();
+        start(requestedMethods);
     } else {
         // check that it didn't finish due to turned off Bluetooth Device
         const int state = adapter.callMethod<jint>("getState");
@@ -204,6 +270,13 @@ void QBluetoothDeviceDiscoveryAgentPrivate::processSdpDiscoveryFinished()
             return;
         }
 
+        // no BTLE scan requested
+        if (!(requestedMethods & QBluetoothDeviceDiscoveryAgent::LowEnergyMethod)) {
+            m_active = NoScanActive;
+            emit q->finished();
+            return;
+        }
+
         // start LE scan if supported
         if (QtAndroidPrivate::androidSdkVersion() < 18) {
             qCDebug(QT_BT_ANDROID) << "Skipping Bluetooth Low Energy device scan";
@@ -234,7 +307,7 @@ void QBluetoothDeviceDiscoveryAgentPrivate::processDiscoveredDevices(
 
     for (int i = 0; i < discoveredDevices.size(); i++) {
         if (discoveredDevices[i].address() == info.address()) {
-            if (discoveredDevices[i] == info) {
+            if (discoveredDevices[i] == info && lowEnergySearchTimeout > 0) {
                 qCDebug(QT_BT_ANDROID) << "Duplicate: " << info.address()
                                        << "isLeScanResult:" << isLeResult;
                 return;
@@ -285,15 +358,21 @@ void QBluetoothDeviceDiscoveryAgentPrivate::startLowEnergyScan()
         return;
     }
 
+    // wait interval and sum up what was found
     if (!leScanTimeout) {
         leScanTimeout = new QTimer(this);
         leScanTimeout->setSingleShot(true);
-        leScanTimeout->setInterval(25000);
         connect(leScanTimeout, &QTimer::timeout,
                 this, &QBluetoothDeviceDiscoveryAgentPrivate::stopLowEnergyScan);
     }
 
-    leScanTimeout->start();
+    if (lowEnergySearchTimeout > 0) { // otherwise no timeout and stop() required
+        leScanTimeout->setInterval(lowEnergySearchTimeout);
+        leScanTimeout->start();
+    }
+
+    qCDebug(QT_BT_ANDROID)
+        << "QBluetoothDeviceDiscoveryAgentPrivate::start() - Low Energy search successfully started.";
 }
 
 void QBluetoothDeviceDiscoveryAgentPrivate::stopLowEnergyScan()
