@@ -1,31 +1,37 @@
 /****************************************************************************
 **
-** Copyright (C) 2015 The Qt Company Ltd.
-** Contact: http://www.qt.io/licensing/
+** Copyright (C) 2016 The Qt Company Ltd.
+** Contact: https://www.qt.io/licensing/
 **
 ** This file is part of the QtBluetooth module of the Qt Toolkit.
 **
-** $QT_BEGIN_LICENSE:LGPL21$
+** $QT_BEGIN_LICENSE:LGPL$
 ** Commercial License Usage
 ** Licensees holding valid commercial Qt licenses may use this file in
 ** accordance with the commercial license agreement provided with the
 ** Software or, alternatively, in accordance with the terms contained in
 ** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see http://www.qt.io/terms-conditions. For further
-** information use the contact form at http://www.qt.io/contact-us.
+** and conditions see https://www.qt.io/terms-conditions. For further
+** information use the contact form at https://www.qt.io/contact-us.
 **
 ** GNU Lesser General Public License Usage
 ** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 2.1 or version 3 as published by the Free
-** Software Foundation and appearing in the file LICENSE.LGPLv21 and
-** LICENSE.LGPLv3 included in the packaging of this file. Please review the
-** following information to ensure the GNU Lesser General Public License
-** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
-** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+** General Public License version 3 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL3 included in the
+** packaging of this file. Please review the following information to
+** ensure the GNU Lesser General Public License version 3 requirements
+** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
 **
-** As a special exception, The Qt Company gives you certain additional
-** rights. These rights are described in The Qt Company LGPL Exception
-** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 2.0 or (at your option) the GNU General
+** Public license version 3 or any later version approved by the KDE Free
+** Qt Foundation. The licenses are as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
+** included in the packaging of this file. Please review the following
+** information to ensure the GNU General Public License requirements will
+** be met: https://www.gnu.org/licenses/gpl-2.0.html and
+** https://www.gnu.org/licenses/gpl-3.0.html.
 **
 ** $QT_END_LICENSE$
 **
@@ -57,7 +63,7 @@
 #include <QtBluetooth/QBluetoothAddress>
 #include <QtBluetooth/QBluetoothLocalDevice>
 
-#ifdef QT_BLUEZ_BLUETOOTH
+#if QT_CONFIG(bluez)
 #include "bluez/bluez5_helper_p.h"
 
 class OrgBluezManagerInterface;
@@ -70,15 +76,21 @@ class OrgBluezDevice1Interface;
 QT_BEGIN_NAMESPACE
 class QDBusVariant;
 QT_END_NAMESPACE
-#elif defined(QT_QNX_BLUETOOTH)
-#include "qnx/ppshelpers_p.h"
-#include <QTimer>
+#endif
+
+#ifdef QT_WINRT_BLUETOOTH
+#include <QtCore/QPointer>
+#include <QtCore/QTimer>
 #endif
 
 QT_BEGIN_NAMESPACE
 
+#ifdef QT_WINRT_BLUETOOTH
+class QWinRTBluetoothDeviceDiscoveryWorker;
+#endif
+
 class QBluetoothDeviceDiscoveryAgentPrivate
-#if defined(QT_QNX_BLUETOOTH) || defined(QT_ANDROID_BLUETOOTH)
+#if defined(QT_ANDROID_BLUETOOTH) || defined(QT_WINRT_BLUETOOTH)
     : public QObject
 {
     Q_OBJECT
@@ -92,11 +104,11 @@ public:
             QBluetoothDeviceDiscoveryAgent *parent);
     ~QBluetoothDeviceDiscoveryAgentPrivate();
 
-    void start();
+    void start(QBluetoothDeviceDiscoveryAgent::DiscoveryMethods methods);
     void stop();
     bool isActive() const;
 
-#ifdef QT_BLUEZ_BLUETOOTH
+#if QT_CONFIG(bluez)
     void _q_deviceFound(const QString &address, const QVariantMap &dict);
     void _q_propertyChanged(const QString &name, const QDBusVariant &value);
     void _q_InterfacesAdded(const QDBusObjectPath &object_path,
@@ -134,7 +146,7 @@ private:
     QTimer *leScanTimeout;
 
     bool pendingCancel, pendingStart;
-#elif defined(QT_BLUEZ_BLUETOOTH)
+#elif QT_CONFIG(bluez)
     QBluetoothAddress m_adapterAddress;
     bool pendingCancel;
     bool pendingStart;
@@ -150,32 +162,21 @@ private:
 
     bool useExtendedDiscovery;
     QTimer extendedDiscoveryTimer;
-
-#elif defined(QT_QNX_BLUETOOTH)
-private slots:
-    void finished();
-    void remoteDevicesChanged(int);
-    void controlReply(ppsResult result);
-    void controlEvent(ppsResult result);
-    void startDeviceSearch();
-
-private:
-    QSocketNotifier *m_rdNotifier;
-    QTimer m_finishedTimer;
-
-    int m_rdfd;
-    bool m_active;
-    enum Ops {
-        None,
-        Cancel,
-        Start
-    };
-    Ops m_nextOp;
-    Ops m_currentOp;
-    void processNextOp();
-    bool isFinished;
 #endif
 
+#ifdef QT_WINRT_BLUETOOTH
+private slots:
+    void registerDevice(const QBluetoothDeviceInfo &info);
+    void onScanFinished();
+
+private:
+    void disconnectAndClearWorker();
+    QPointer<QWinRTBluetoothDeviceDiscoveryWorker> worker;
+    QTimer *leScanTimer;
+#endif
+
+    int lowEnergySearchTimeout;
+    QBluetoothDeviceDiscoveryAgent::DiscoveryMethods requestedMethods;
     QBluetoothDeviceDiscoveryAgent *q_ptr;
 };
 
