@@ -164,6 +164,8 @@ QBluetoothServiceDiscoveryAgent::QBluetoothServiceDiscoveryAgent(QObject *parent
     \l InvalidBluetoothAdapterError. Therefore it is recommended to test the error flag immediately after
     using this constructor.
 
+    \note On WinRT the passed adapter address will be ignored.
+
     \sa error()
 */
 QBluetoothServiceDiscoveryAgent::QBluetoothServiceDiscoveryAgent(const QBluetoothAddress &deviceAdapter, QObject *parent)
@@ -311,7 +313,7 @@ void QBluetoothServiceDiscoveryAgent::start(DiscoveryMode mode)
 
     if (d->discoveryState() == QBluetoothServiceDiscoveryAgentPrivate::Inactive
             && d->error != InvalidBluetoothAdapterError) {
-#ifdef QT_BLUEZ_BLUETOOTH
+#if QT_CONFIG(bluez)
         // done to avoid repeated parsing for adapter address
         // on Bluez5
         d->foundHostAdapterPath.clear();
@@ -424,7 +426,7 @@ void QBluetoothServiceDiscoveryAgentPrivate::startDeviceDiscovery()
     Q_Q(QBluetoothServiceDiscoveryAgent);
 
     if (!deviceDiscoveryAgent) {
-#ifdef QT_BLUEZ_BLUETOOTH
+#if QT_CONFIG(bluez)
         deviceDiscoveryAgent = new QBluetoothDeviceDiscoveryAgent(m_deviceAdapterAddress, q);
 #else
         deviceDiscoveryAgent = new QBluetoothDeviceDiscoveryAgent(q);
@@ -440,7 +442,7 @@ void QBluetoothServiceDiscoveryAgentPrivate::startDeviceDiscovery()
 
     setDiscoveryState(DeviceDiscovery);
 
-    deviceDiscoveryAgent->start();
+    deviceDiscoveryAgent->start(QBluetoothDeviceDiscoveryAgent::ClassicMethod);
 }
 
 /*!
@@ -448,6 +450,10 @@ void QBluetoothServiceDiscoveryAgentPrivate::startDeviceDiscovery()
 */
 void QBluetoothServiceDiscoveryAgentPrivate::stopDeviceDiscovery()
 {
+    // disconnect to avoid recursion during stop() - QTBUG-60131
+    // we don't care about a potential signals from device discovery agent anymore
+    deviceDiscoveryAgent->disconnect();
+
     deviceDiscoveryAgent->stop();
     delete deviceDiscoveryAgent;
     deviceDiscoveryAgent = 0;
@@ -495,6 +501,10 @@ void QBluetoothServiceDiscoveryAgentPrivate::_q_deviceDiscoveryError(QBluetoothD
     error = static_cast<QBluetoothServiceDiscoveryAgent::Error>(newError);
     errorString = deviceDiscoveryAgent->errorString();
 
+    // disconnect to avoid recursion during stop() - QTBUG-60131
+    // we don't care about a potential signals from device discovery agent anymore
+    deviceDiscoveryAgent->disconnect();
+
     deviceDiscoveryAgent->stop();
     delete deviceDiscoveryAgent;
     deviceDiscoveryAgent = 0;
