@@ -400,7 +400,17 @@ void QLowEnergyControllerPrivate::connectToDevice()
             Q_ASSERT_SUCCEEDED(hr);
             ComPtr<IGattReadResult> result;
             hr = QWinRTFunctions::await(op, result.GetAddressOf());
-            Q_ASSERT_SUCCEEDED(hr);
+            if (hr == E_INVALIDARG) {
+                // E_INVALIDARG happens when user tries to connect to a device that was paired
+                // before but is not available.
+                qCDebug(QT_BT_WINRT) << "Could not obtain characteristic read result that triggers"
+                                        "device connection. Is the device reachable?";
+                setError(QLowEnergyController::ConnectionError);
+                setState(QLowEnergyController::UnconnectedState);
+                return;
+            } else {
+                Q_ASSERT_SUCCEEDED(hr);
+            }
             ComPtr<ABI::Windows::Storage::Streams::IBuffer> buffer;
             hr = result->get_Value(&buffer);
             Q_ASSERT_SUCCEEDED(hr);
@@ -489,7 +499,9 @@ void QLowEnergyControllerPrivate::obtainIncludedServices(QSharedPointer<QLowEner
     Q_ASSERT_SUCCEEDED(hr);
     ComPtr<IVectorView<GattDeviceService *>> includedServices;
     hr = service2->GetAllIncludedServices(&includedServices);
-    Q_ASSERT_SUCCEEDED(hr);
+    // Some devices return ERROR_ACCESS_DISABLED_BY_POLICY
+    if (FAILED(hr))
+        return;
 
     uint count;
     hr = includedServices->get_Size(&count);
@@ -588,7 +600,12 @@ void QLowEnergyControllerPrivate::discoverServiceDetails(const QBluetoothUuid &s
     Q_ASSERT_SUCCEEDED(hr);
     ComPtr<IVectorView<GattDeviceService *>> deviceServices;
     hr = deviceService2->GetAllIncludedServices(&deviceServices);
-    Q_ASSERT_SUCCEEDED(hr);
+    if (FAILED(hr)) { // ERROR_ACCESS_DISABLED_BY_POLICY
+        qCDebug(QT_BT_WINRT) << "Could not obtain included services list for" << service;
+        pointer->setError(QLowEnergyService::UnknownError);
+        pointer->setState(QLowEnergyService::InvalidService);
+        return;
+    }
     uint serviceCount;
     hr = deviceServices->get_Size(&serviceCount);
     Q_ASSERT_SUCCEEDED(hr);
