@@ -505,7 +505,7 @@ void tst_QBluetoothSocket::tst_preferredSecurityFlags()
     //test default values
 #if defined(QT_ANDROID_BLUETOOTH) | defined(QT_OSX_BLUETOOTH)
     QCOMPARE(socket.preferredSecurityFlags(), QBluetooth::Secure);
-#elif defined(QT_BLUEZ_BLUETOOTH)
+#elif QT_CONFIG(bluez)
     QCOMPARE(socket.preferredSecurityFlags(), QBluetooth::Authorization);
 #else
     QCOMPARE(socket.preferredSecurityFlags(), QBluetooth::NoSecurity);
